==> cdk-cx-api-1.18.0-sources.jar: software/amazon/awscdk/cxapi/FileAssetMetadataEntry.java <==
package software.amazon.awscdk.cxapi;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.8 (build bd5ef4d)", date = "2019-11-25T14:22:09.254Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.FileAssetMetadataEntry")
@software.amazon.jsii.Jsii.Proxy(FileAssetMetadataEntry.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface FileAssetMetadataEntry extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the parameter where the hash of the bundled asset should be passed in.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getArtifactHashParameter();

    /**
     * Logical identifier for the asset.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getId();

    /**
     * Requested packaging style.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getPackaging();

    /**
     * Path on disk to the asset.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getPath();

    /**
     * Name of parameter where S3 bucket should be passed in.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getS3BucketParameter();

    /**
     * Name of parameter where S3 key should be passed in.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getS3KeyParameter();

    /**
     * The hash of the source directory used to build the asset.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getSourceHash();

    /**
     * @return a {@link Builder} of {@link FileAssetMetadataEntry}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link FileAssetMetadataEntry}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private java.lang.String artifactHashParameter;
        private java.lang.String id;
        private java.lang.String packaging;
        private java.lang.String path;
        private java.lang.String s3BucketParameter;
        private java.lang.String s3KeyParameter;
        private java.lang.String sourceHash;

        /**
         * Sets the value of ArtifactHashParameter
         * @param artifactHashParameter The name of the parameter where the hash of the bundled asset should be passed in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactHashParameter(java.lang.String artifactHashParameter) {
            this.artifactHashParameter = artifactHashParameter;
            return this;
        }

        /**
         * Sets the value of Id
         * @param id Logical identifier for the asset. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder id(java.lang.String id) {
            this.id = id;
            return this;
        }

        /**
         * Sets the value of Packaging
         * @param packaging Requested packaging style. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder packaging(java.lang.String packaging) {
            this.packaging = packaging;
            return this;
        }

        /**
         * Sets the value of Path
         * @param path Path on disk to the asset. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder path(java.lang.String path) {
            this.path = path;
            return this;
        }

        /**
         * Sets the value of S3BucketParameter
         * @param s3BucketParameter Name of parameter where S3 bucket should be passed in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder s3BucketParameter(java.lang.String s3BucketParameter) {
            this.s3BucketParameter = s3BucketParameter;
            return this;
        }

        /**
         * Sets the value of S3KeyParameter
         * @param s3KeyParameter Name of parameter where S3 key should be passed in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder s3KeyParameter(java.lang.String s3KeyParameter) {
            this.s3KeyParameter = s3KeyParameter;
            return this;
        }

        /**
         * Sets the value of SourceHash
         * @param sourceHash The hash of the source directory used to build the asset. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sourceHash(java.lang.String sourceHash) {
            this.sourceHash = sourceHash;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FileAssetMetadataEntry}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public FileAssetMetadataEntry build() {
            return new Jsii$Proxy(artifactHashParameter, id, packaging, path, s3BucketParameter, s3KeyParameter, sourceHash);
        }
    }

    /**
     * An implementation for {@link FileAssetMetadataEntry}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FileAssetMetadataEntry {
        private final java.lang.String artifactHashParameter;
        private final java.lang.String id;
        private final java.lang.String packaging;
        private final java.lang.String path;
        private final java.lang.String s3BucketParameter;
        private final java.lang.String s3KeyParameter;
        private final java.lang.String sourceHash;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.artifactHashParameter = this.jsiiGet("artifactHashParameter", java.lang.String.class);
            this.id = this.jsiiGet("id", java.lang.String.class);
            this.packaging = this.jsiiGet("packaging", java.lang.String.class);
            this.path = this.jsiiGet("path", java.lang.String.class);
            this.s3BucketParameter = this.jsiiGet("s3BucketParameter", java.lang.String.class);
            this.s3KeyParameter = this.jsiiGet("s3KeyParameter", java.lang.String.class);
            this.sourceHash = this.jsiiGet("sourceHash", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String artifactHashParameter, final java.lang.String id, final java.lang.String packaging, final java.lang.String path, final java.lang.String s3BucketParameter, final java.lang.String s3KeyParameter, final java.lang.String sourceHash) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.artifactHashParameter = java.util.Objects.requireNonNull(artifactHashParameter, "artifactHashParameter is required");
            this.id = java.util.Objects.requireNonNull(id, "id is required");
            this.packaging = java.util.Objects.requireNonNull(packaging, "packaging is required");
            this.path = java.util.Objects.requireNonNull(path, "path is required");
            this.s3BucketParameter = java.util.Objects.requireNonNull(s3BucketParameter, "s3BucketParameter is required");
            this.s3KeyParameter = java.util.Objects.requireNonNull(s3KeyParameter, "s3KeyParameter is required");
            this.sourceHash = java.util.Objects.requireNonNull(sourceHash, "sourceHash is required");
        }

        @Override
        public java.lang.String getArtifactHashParameter() {
            return this.artifactHashParameter;
        }

        @Override
        public java.lang.String getId() {
            return this.id;
        }

        @Override
        public java.lang.String getPackaging() {
            return this.packaging;
        }

        @Override
        public java.lang.String getPath() {
            return this.path;
        }

        @Override
        public java.lang.String getS3BucketParameter() {
            return this.s3BucketParameter;
        }

        @Override
        public java.lang.String getS3KeyParameter() {
            return this.s3KeyParameter;
        }

        @Override
        public java.lang.String getSourceHash() {
            return this.sourceHash;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("artifactHashParameter", om.valueToTree(this.getArtifactHashParameter()));
            data.set("id", om.valueToTree(this.getId()));
            data.set("packaging", om.valueToTree(this.getPackaging()));
            data.set("path", om.valueToTree(this.getPath()));
            data.set("s3BucketParameter", om.valueToTree(this.getS3BucketParameter()));
            data.set("s3KeyParameter", om.valueToTree(this.getS3KeyParameter()));
            data.set("sourceHash", om.valueToTree(this.getSourceHash()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/cx-api.FileAssetMetadataEntry"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FileAssetMetadataEntry.Jsii$Proxy that = (FileAssetMetadataEntry.Jsii$Proxy) o;

            if (!artifactHashParameter.equals(that.artifactHashParameter)) return false;
            if (!id.equals(that.id)) return false;
            if (!packaging.equals(that.packaging)) return false;
            if (!path.equals(that.path)) return false;
            if (!s3BucketParameter.equals(that.s3BucketParameter)) return false;
            if (!s3KeyParameter.equals(that.s3KeyParameter)) return false;
            return this.sourceHash.equals(that.sourceHash);
        }

        @Override
        public int hashCode() {
            int result = this.artifactHashParameter.hashCode();
            result = 31 * result + (this.id.hashCode());
            result = 31 * result + (this.packaging.hashCode());
            result = 31 * result + (this.path.hashCode());
            result = 31 * result + (this.s3BucketParameter.hashCode());
            result = 31 * result + (this.s3KeyParameter.hashCode());
            result = 31 * result + (this.sourceHash.hashCode());
            return result;
        }
    }
}

==> cdk-cx-api-1.19.0-sources.jar: software/amazon/awscdk/cxapi/FileAssetMetadataEntry.java <==
package software.amazon.awscdk.cxapi;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.11 (build d4fd44f)", date = "2019-12-17T13:05:19.381Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.FileAssetMetadataEntry")
@software.amazon.jsii.Jsii.Proxy(FileAssetMetadataEntry.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface FileAssetMetadataEntry extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the parameter where the hash of the bundled asset should be passed in.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getArtifactHashParameter();

    /**
     * Logical identifier for the asset.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getId();

    /**
     * Requested packaging style.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getPackaging();

    /**
     * Path on disk to the asset.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getPath();

    /**
     * Name of parameter where S3 bucket should be passed in.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getS3BucketParameter();

    /**
     * Name of parameter where S3 key should be passed in.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getS3KeyParameter();

    /**
     * The hash of the source directory used to build the asset.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getSourceHash();

    /**
     * @return a {@link Builder} of {@link FileAssetMetadataEntry}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link FileAssetMetadataEntry}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private java.lang.String artifactHashParameter;
        private java.lang.String id;
        private java.lang.String packaging;
        private java.lang.String path;
        private java.lang.String s3BucketParameter;
        private java.lang.String s3KeyParameter;
        private java.lang.String sourceHash;

        /**
         * Sets the value of {@link FileAssetMetadataEntry#getArtifactHashParameter}
         * @param artifactHashParameter The name of the parameter where the hash of the bundled asset should be passed in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactHashParameter(java.lang.String artifactHashParameter) {
            this.artifactHashParameter = artifactHashParameter;
            return this;
        }

        /**
         * Sets the value of {@link FileAssetMetadataEntry#getId}
         * @param id Logical identifier for the asset. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder id(java.lang.String id) {
            this.id = id;
            return this;
        }

        /**
         * Sets the value of {@link FileAssetMetadataEntry#getPackaging}
         * @param packaging Requested packaging style. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder packaging(java.lang.String packaging) {
            this.packaging = packaging;
            return this;
        }

        /**
         * Sets the value of {@link FileAssetMetadataEntry#getPath}
         * @param path Path on disk to the asset. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder path(java.lang.String path) {
            this.path = path;
            return this;
        }

        /**
         * Sets the value of {@link FileAssetMetadataEntry#getS3BucketParameter}
         * @param s3BucketParameter Name of parameter where S3 bucket should be passed in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder s3BucketParameter(java.lang.String s3BucketParameter) {
            this.s3BucketParameter = s3BucketParameter;
            return this;
        }

        /**
         * Sets the value of {@link FileAssetMetadataEntry#getS3KeyParameter}
         * @param s3KeyParameter Name of parameter where S3 key should be passed in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder s3KeyParameter(java.lang.String s3KeyParameter) {
            this.s3KeyParameter = s3KeyParameter;
            return this;
        }

        /**
         * Sets the value of {@link FileAssetMetadataEntry#getSourceHash}
         * @param sourceHash The hash of the source directory used to build the asset. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sourceHash(java.lang.String sourceHash) {
            this.sourceHash = sourceHash;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FileAssetMetadataEntry}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public FileAssetMetadataEntry build() {
            return new Jsii$Proxy(artifactHashParameter, id, packaging, path, s3BucketParameter, s3KeyParameter, sourceHash);
        }
    }

    /**
     * An implementation for {@link FileAssetMetadataEntry}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FileAssetMetadataEntry {
        private final java.lang.String artifactHashParameter;
        private final java.lang.String id;
        private final java.lang.String packaging;
        private final java.lang.String path;
        private final java.lang.String s3BucketParameter;
        private final java.lang.String s3KeyParameter;
        private final java.lang.String sourceHash;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.artifactHashParameter = this.jsiiGet("artifactHashParameter", java.lang.String.class);
            this.id = this.jsiiGet("id", java.lang.String.class);
            this.packaging = this.jsiiGet("packaging", java.lang.String.class);
            this.path = this.jsiiGet("path", java.lang.String.class);
            this.s3BucketParameter = this.jsiiGet("s3BucketParameter", java.lang.String.class);
            this.s3KeyParameter = this.jsiiGet("s3KeyParameter", java.lang.String.class);
            this.sourceHash = this.jsiiGet("sourceHash", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String artifactHashParameter, final java.lang.String id, final java.lang.String packaging, final java.lang.String path, final java.lang.String s3BucketParameter, final java.lang.String s3KeyParameter, final java.lang.String sourceHash) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.artifactHashParameter = java.util.Objects.requireNonNull(artifactHashParameter, "artifactHashParameter is required");
            this.id = java.util.Objects.requireNonNull(id, "id is required");
            this.packaging = java.util.Objects.requireNonNull(packaging, "packaging is required");
            this.path = java.util.Objects.requireNonNull(path, "path is required");
            this.s3BucketParameter = java.util.Objects.requireNonNull(s3BucketParameter, "s3BucketParameter is required");
            this.s3KeyParameter = java.util.Objects.requireNonNull(s3KeyParameter, "s3KeyParameter is required");
            this.sourceHash = java.util.Objects.requireNonNull(sourceHash, "sourceHash is required");
        }

        @Override
        public java.lang.String getArtifactHashParameter() {
            return this.artifactHashParameter;
        }

        @Override
        public java.lang.String getId() {
            return this.id;
        }

        @Override
        public java.lang.String getPackaging() {
            return this.packaging;
        }

        @Override
        public java.lang.String getPath() {
            return this.path;
        }

        @Override
        public java.lang.String getS3BucketParameter() {
            return this.s3BucketParameter;
        }

        @Override
        public java.lang.String getS3KeyParameter() {
            return this.s3KeyParameter;
        }

        @Override
        public java.lang.String getSourceHash() {
            return this.sourceHash;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("artifactHashParameter", om.valueToTree(this.getArtifactHashParameter()));
            data.set("id", om.valueToTree(this.getId()));
            data.set("packaging", om.valueToTree(this.getPackaging()));
            data.set("path", om.valueToTree(this.getPath()));
            data.set("s3BucketParameter", om.valueToTree(this.getS3BucketParameter()));
            data.set("s3KeyParameter", om.valueToTree(this.getS3KeyParameter()));
            data.set("sourceHash", om.valueToTree(this.getSourceHash()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/cx-api.FileAssetMetadataEntry"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FileAssetMetadataEntry.Jsii$Proxy that = (FileAssetMetadataEntry.Jsii$Proxy) o;

            if (!artifactHashParameter.equals(that.artifactHashParameter)) return false;
            if (!id.equals(that.id)) return false;
            if (!packaging.equals(that.packaging)) return false;
            if (!path.equals(that.path)) return false;
            if (!s3BucketParameter.equals(that.s3BucketParameter)) return false;
            if (!s3KeyParameter.equals(that.s3KeyParameter)) return false;
            return this.sourceHash.equals(that.sourceHash);
        }

        @Override
        public int hashCode() {
            int result = this.artifactHashParameter.hashCode();
            result = 31 * result + (this.id.hashCode());
            result = 31 * result + (this.packaging.hashCode());
            result = 31 * result + (this.path.hashCode());
            result = 31 * result + (this.s3BucketParameter.hashCode());
            result = 31 * result + (this.s3KeyParameter.hashCode());
            result = 31 * result + (this.sourceHash.hashCode());
            return result;
        }
    }
}
